@@ -1,6 +1,35 @@
 #include "proximityd.h"
 
 
+Client::Client(int pid_, int interval_):pid(pid_),interval(interval_)
+{
+
+
+
+}
+
+
+void ProximityDaemon::setInterval()
+{
+	int iint;
+	
+	debug("Setting Interval");
+	for (int i=0;i<pids.size();++i)
+	{
+		if (i==0)
+			iint=pids[i]->interval;
+
+		iint=std::min(iint,pids[i]->interval);
+	}
+	if (iint<50)
+		iint=50;
+	if (iint>2000)
+		iint=2000;
+	
+	intervalUsec=1000*iint;
+}
+
+
 
 int ProximityDaemon::checkProcess()
 {
@@ -18,20 +47,22 @@ int ProximityDaemon::checkProcess()
 			
 			for (int i=0; i<pids.size(); ++i)
 			{
-				if (ppid==pids[i])
+				if (ppid==pids[i]->pid)
 				{
-					toKeep.push_back(ppid);
+					toKeep.push_back(new Client(ppid,pids[i]->interval));
 					break;
 				}
 			}
 		}
-	}
+	} 
 	pids.swap(toKeep);
-
+	setInterval();
+	
 	if (pids.size()==0)
 	{
 		active=0;
 		intervalUsec=INTERVAL_IDLE;
+		debug("TURNED OFF");
 	}	
 	closedir(dir_p);
 	return 0;
@@ -49,33 +80,72 @@ void ProximityDaemon::listen()
 		if (NULL != msgMth)
 		{		
 		 	if (dbus_message_is_method_call(msgMth, "proximityd.method.change", "Change"))
+			{
 				handleMethodCall();
+			}
 		} 
       	}
 }
 
+void ProximityDaemon::changeInterval(int mInterval_, int pid_)
+{
+
+	for (int i=0;i<pids.size();++i)
+	{
+		if (pids[i]->pid==pid_)
+		{
+			pids[i]->interval=mInterval_;
+			setInterval();
+			return;
+		}
+
+	}
+
+	
+}
+
+
+void ProximityDaemon::debug(const char* message)
+{
+
+	if (debugFlag==1)
+	{
+		std::cout<<"PROXIMITYD: "<<message<<std::endl;
+	}
+
+}
+
+
 void ProximityDaemon::handleMethodCall()
 {
 
+	debug("Handling Message");
 
 	bool stat = true;
 	dbus_uint32_t serial = 0;
 		
-
+	intervalMth=0;
+	
 	if (!dbus_message_iter_init(msgMth, &argsMth))
-		std::cout<<"PROXIMITY: Message has no arguments"<<std::endl;
+		debug("Message has no arguments");
 	else if (DBUS_TYPE_STRING != dbus_message_iter_get_arg_type(&argsMth))
-		std::cout<<"PROXIMITY: Argument is not string"<<std::endl;
+		debug("Argument is not string");
 	else
       		dbus_message_iter_get_basic(&argsMth, &paramMth);
 
 	if (!dbus_message_iter_next(&argsMth))
-	std::cout<<"PROXIMITY: Message has too few arguments"<<std::endl;
+		debug("Message has too few arguments");
 	else if (DBUS_TYPE_INT32 != dbus_message_iter_get_arg_type(&argsMth))
-		std::cout<<"PROXIMITY: Argument is not int"<<std::endl;
+		debug("Argument is not int");
 	else
       		dbus_message_iter_get_basic(&argsMth, &paramMthPid);
+	
 
+	if (dbus_message_iter_next(&argsMth))
+	{
+		if (DBUS_TYPE_INT32==dbus_message_iter_get_arg_type(&argsMth))
+			dbus_message_iter_get_basic(&argsMth, &intervalMth);
+	}	
 	
 	
 	if (strcmp(paramMth,"turnOff")==0 && paramMthPid!=0)
@@ -88,6 +158,12 @@ void ProximityDaemon::handleMethodCall()
 	{
 		turnOn();
 	}
+
+	else if (strcmp(paramMth,"changeInterval")==0 && paramMthPid!=0 && intervalMth!=0)
+	{
+		changeInterval(intervalMth, paramMthPid);
+	}
+
 	
 	replyMth = dbus_message_new_method_return(msgMth);
 		
@@ -101,18 +177,22 @@ void ProximityDaemon::handleMethodCall()
 	}
 	else 
 	{
-		rep = "turnedOn";
+
+		if (intervalMth!=0)
+			rep="intervalRegistered";
+		else
+			rep = "turnedOn";
 	}
 
 	if (!dbus_message_iter_append_basic(&argsMth, DBUS_TYPE_STRING, &rep)) 
 	{
-		std::cout<<"PROXIMITY: Out Of Memory"<<std::endl;
+		debug("Out Of Memory");
 		return;
 	}
 	
 	if (!dbus_connection_send(connMth, replyMth, &serial)) 
 	{
-		std::cout<<"PROXIMITY: Out Of Memory"<<std::endl;
+		debug("PROXIMITY: Out Of Memory");
       		return;
 	}
 	
@@ -125,9 +205,10 @@ void ProximityDaemon::turnOff()
 	
 	for (int i=0; i<pids.size();++i)
 	{
-		if (pids[i]==paramMthPid)
+		if (pids[i]->pid==paramMthPid)
 		{
 			pids.erase(pids.begin()+i);
+			setInterval();
 			break;
 		}
 	}
@@ -136,6 +217,7 @@ void ProximityDaemon::turnOff()
 	{
 		active=0;
 		intervalUsec=INTERVAL_IDLE;
+		debug("TURNED OFF");
 	}
 	
 
@@ -145,9 +227,12 @@ void ProximityDaemon::turnOff()
 
 void ProximityDaemon::turnOn()
 {
-	pids.push_back(paramMthPid);
+	pids.push_back(new Client(paramMthPid,100));
+	debug("PUSHED");
+	setInterval();
+	debug("INTERVAL SET");
 	active=1;
-	intervalUsec=INTERVAL_ACTIVE;
+	debug("TURNED ON");
 }
 
 
@@ -160,25 +245,25 @@ void ProximityDaemon::connectToDbusMethod()
 
 	if (dbus_error_is_set(&errMth)) 
 	{
-		std::cout<<"PROXIMITY: Connection Error"<<errMth.message<<std::endl;
+		debug("Connection Error");
 		dbus_error_free(&errMth);
 	}
 	if (NULL == connMth) 
 	{
-		std::cout<<"PROXIMITY: Connection Null"<<std::endl;
+		debug("Connection Null");
 		exit(1);
 	}
 
 	retMth = dbus_bus_request_name(connMth, "proximityd.method.change", DBUS_NAME_FLAG_REPLACE_EXISTING , &errMth);
 	if (dbus_error_is_set(&errMth)) 
 	{
-		std::cout<<"PROXIMITY: Name Error"<<errMth.message<<std::endl;
+		debug("Name Error");
 		dbus_error_free(&errMth);
 	}
 	      
 	if (DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER != retMth) 
 	{
-		std::cout<<"PROXIMITY: Not Primary Owner"<<std::endl;
+		debug("Not Primary Owner");
 		exit(1);
 	}
 	      
@@ -189,9 +274,11 @@ void ProximityDaemon::connectToDbusMethod()
 }
 
 
-ProximityDaemon::ProximityDaemon()
+ProximityDaemon::ProximityDaemon(int debugFlag_)
 {
 
+	debugFlag=debugFlag_;
+	debug("Debug Mode ON");
 	intervalUsec=INTERVAL_IDLE;
 	active=0;
 	currentState='n';
@@ -200,8 +287,8 @@ ProximityDaemon::ProximityDaemon()
 
 	connectToDbusSignal();
 	connectToDbusMethod();
-	readProx();
 	counterCheck=0;
+	readProx();
 }
 
 ProximityDaemon::~ProximityDaemon()
@@ -219,9 +306,10 @@ void ProximityDaemon::readProx()
 
 	}
 
-	 
+	  
 	while(1)
 	{
+		debug("*");
 		listen();
 		if (active)
 		{
@@ -280,21 +368,21 @@ void ProximityDaemon::emitState(char newState_)
 
 	if (NULL == msgSig)
 	{
-		std::cout<<"PROXIMITY: Message Null"<<std::endl;
+		debug("Message Null");
 		return;
 	}
 
 	dbus_message_iter_init_append(msgSig, &argsSig);
 	if (!dbus_message_iter_append_basic(&argsSig, DBUS_TYPE_STRING, &sigvalue)) 
 	{
-		std::cout<<"PROXIMITY: Out of Memory"<<std::endl;
+		debug("Out of Memory");
 		return;
 	}
 	   
 
 	if (!dbus_connection_send(connSig, msgSig, &serialSig)) 
 	{	
-		std::cout<<"PROXIMITY: Out of Memory"<<std::endl;
+		debug("Out of Memory");
 		return;
 	}
 	   
@@ -312,7 +400,7 @@ void ProximityDaemon::connectToDbusSignal()
 	
 	if (dbus_error_is_set(&errSig)) 
 	{
-		std::cout<<"PROXIMITY: Connection error"<<std::endl;
+		debug("Connection error");
 		dbus_error_free(&errSig);
 	}
 	
@@ -325,7 +413,7 @@ void ProximityDaemon::connectToDbusSignal()
 	
 	if (dbus_error_is_set(&errSig)) 
 	{
-		std::cout<<"PROXIMITY: Name error"<<std::endl;
+		debug("Name error");
 		dbus_error_free(&errSig);
 	}
 	if (DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER != retSig) 
@@ -343,10 +431,22 @@ void ProximityDaemon::connectToDbusSignal()
 
 int main(int argc, char **argv)
 {
-	ProximityDaemon* pd = new ProximityDaemon();
 	
-
-
+	
+	
+	if (argc>1)
+	{
+		if (strcmp(argv[1],"db")==0)
+		{
+			
+			ProximityDaemon* pd = new ProximityDaemon(1);
+			
+		}
+		else 
+			ProximityDaemon* pd = new ProximityDaemon(0);
+	}
+	else 
+		ProximityDaemon* pd = new ProximityDaemon(0);
 	
 
 return 0;
