@@ -6,14 +6,27 @@
 #include <dbus/dbus.h>
 #include <vector>
 #include <cstring>
-
+#include <cmath>
 #include <dirent.h>
-#include <stdio.h>
-#include <stdlib.h>
 
-#define INTERVAL_IDLE 2000000
+#define INTERVAL_IDLE 1000000
 #define INTERVAL_ACTIVE 100000
 
+class Client
+{
+	public:
+		int pid;
+	       	int interval;
+
+		Client(int pid_, int interval_);	
+
+
+
+
+
+};
+
+
 class ProximityDaemon
 {
 
@@ -53,18 +66,24 @@ class ProximityDaemon
 		int retMth;
 		char* paramMth;
 		int paramMthPid;
-
+		int intervalMth;
 		int connectedMth;
 				  
-		std::vector<int> pids;
+		void changeInterval(int mInterval_, int pid_);
+		
+		std::vector<Client*> pids;
 		int checkProcess();
 		int counterCheck;
-		std::vector<int> toKeep;
+		std::vector<Client*> toKeep;
+		void setInterval();
+
 		
+		int debugFlag;
 	public:
-		ProximityDaemon();
+		ProximityDaemon(int debugFlag_);
 		~ProximityDaemon();
 		
+		void debug(const char* message);
 
 
 
